import { provide, inject, defineComponent, ref, computed, unref, onMounted, createVNode, createTextVNode, Fragment, Comment, onBeforeUpdate, reactive, watch, onUnmounted, onDeactivated, onBeforeUnmount, cloneVNode, mergeProps, isVNode, nextTick } from "vue";
import { useState, onMountedOrActivated } from "@gx-design-vue/pro-hooks";
import { getPrefixCls, on, off, getSlot } from "@gx-design-vue/pro-utils";
var config = "";
var style$2 = "";
const swiperPorps = {
  keyboard: Boolean,
  showArrow: Boolean,
  autoplay: Boolean,
  draggable: Boolean,
  touchable: {
    type: Boolean,
    default: true
  },
  loop: {
    type: Boolean,
    default: true
  },
  spaceBetween: {
    type: Number,
    default: 0
  },
  currentIndex: Number,
  defaultIndex: {
    type: Number,
    default: 0
  },
  interval: {
    type: Number,
    default: 5e3
  },
  duration: {
    type: Number,
    default: 300
  },
  effect: {
    type: String,
    default: "slide"
  },
  direction: {
    type: String,
    default: "horizontal"
  },
  dotPlacement: {
    type: String,
    default: "bottom"
  },
  dotType: {
    type: String,
    default: "dot"
  },
  showDots: {
    type: Boolean,
    default: true
  },
  trigger: {
    type: String,
    default: "click"
  },
  arrow: {
    type: [Function, Object, Array]
  },
  dots: {
    type: [Function, Object, Array]
  },
  "onUpdate:currentIndex": Function,
  onChange: Function
};
const swiperContextInjectKey = Symbol("swiper-context");
const useContext = (contextInjectKey = Symbol(), defaultValue) => {
  return inject(contextInjectKey, defaultValue || {});
};
const provideSwiperContext = (value) => {
  provide(swiperContextInjectKey, value);
};
const useSwiperContext = () => useContext(swiperContextInjectKey, []);
const isCarouselItem = (child) => {
  var _a;
  return ((_a = child.type) == null ? void 0 : _a.name) === "SwiperItem";
};
const SwiperItem = defineComponent({
  inheritAttrs: false,
  props: {
    className: String
  },
  setup(props, {
    slots
  }) {
    const item = ref();
    const {
      size,
      parentProps,
      children,
      slideStyle,
      getSlideIndex,
      isActive
    } = useSwiperContext();
    const [offset, setOffset] = useState(0);
    const indexRef = computed(() => {
      return item.value ? getSlideIndex(item.value) : -1;
    });
    const isActiveRef = computed(() => isActive(indexRef.value));
    const style2 = computed(() => {
      const style3 = {};
      if (size.value) {
        style3[unref(parentProps).direction === "vertical" ? "height" : "width"] = `${size.value}px`;
      }
      if (offset.value) {
        style3.transform = `translate${unref(parentProps).direction === "vertical" ? "Y" : "X"}(${offset.value}px)`;
      }
      if (unref(parentProps).spaceBetween) {
        style3.marginRight = `${unref(parentProps).spaceBetween}px`;
      }
      return {
        ...style3,
        ...slideStyle.value || {}
      };
    });
    onMounted(() => {
      children.value.push({
        setOffset,
        ref: item.value
      });
    });
    return () => {
      var _a;
      return createVNode("div", {
        "ref": item,
        "class": [`${props.className}-item`, {
          [`${props.className}-item-current`]: isActiveRef.value
        }],
        "style": style2.value
      }, [(_a = slots.default) == null ? void 0 : _a.call(slots)]);
    };
  }
});
const inBrowser = typeof window !== "undefined";
function isTouchEvent(e) {
  return window.TouchEvent && e instanceof window.TouchEvent;
}
function numSum(targetNum, sumNum) {
  if (sumNum <= 0)
    return targetNum;
  return targetNum > 0 ? targetNum + sumNum : targetNum - sumNum;
}
function flatten(vNodes, filterCommentNode = true, result = []) {
  vNodes.forEach((vNode) => {
    if (vNode === null)
      return;
    if (typeof vNode !== "object") {
      if (typeof vNode === "string" || typeof vNode === "number") {
        result.push(createTextVNode(String(vNode)));
      }
      return;
    }
    if (Array.isArray(vNode)) {
      flatten(vNode, filterCommentNode, result);
      return;
    }
    if (vNode.type === Fragment) {
      if (vNode.children === null)
        return;
      if (Array.isArray(vNode.children)) {
        flatten(vNode.children, filterCommentNode, result);
      }
    } else if (vNode.type !== Comment) {
      result.push(vNode);
    }
  });
  return result;
}
const clamp = (num, min, max) => Math.min(Math.max(num, min), max);
function filterCarouselItem(vnodes) {
  return vnodes.reduce((carouselItems, vnode) => {
    if (isCarouselItem(vnode)) {
      carouselItems.push(vnode);
    }
    return carouselItems;
  }, []);
}
function raf(fn) {
  return inBrowser ? requestAnimationFrame(fn) : -1;
}
function doubleRaf(fn) {
  raf(() => raf(fn));
}
function indexMap(total) {
  return Array.from({ length: total }).map((_, key) => key);
}
function getDirection(x, y) {
  if (x > y) {
    return "horizontal";
  }
  if (y > x) {
    return "vertical";
  }
  return "";
}
function useTouch() {
  const startX = ref(0);
  const startY = ref(0);
  const deltaX = ref(0);
  const deltaY = ref(0);
  const offsetX = ref(0);
  const offsetY = ref(0);
  const direction = ref("");
  const isVertical = () => direction.value === "vertical";
  const isHorizontal = () => direction.value === "horizontal";
  const reset = () => {
    deltaX.value = 0;
    deltaY.value = 0;
    offsetX.value = 0;
    offsetY.value = 0;
    direction.value = "";
  };
  const start = (event) => {
    reset();
    const touchEvent = isTouchEvent(event) ? event.touches[0] : event;
    startX.value = touchEvent.clientX;
    startY.value = touchEvent.clientY;
  };
  const move = (event) => {
    const touchEvent = isTouchEvent(event) ? event.touches[0] : event;
    deltaX.value = (touchEvent.clientX < 0 ? 0 : touchEvent.clientX) - startX.value;
    deltaY.value = touchEvent.clientY - startY.value;
    offsetX.value = Math.abs(deltaX.value);
    offsetY.value = Math.abs(deltaY.value);
    const LOCK_DIRECTION_DISTANCE = 10;
    if (!direction.value || offsetX.value < LOCK_DIRECTION_DISTANCE && offsetY.value < LOCK_DIRECTION_DISTANCE) {
      direction.value = getDirection(offsetX.value, offsetY.value);
    }
  };
  return {
    move,
    start,
    reset,
    startX,
    startY,
    deltaX,
    deltaY,
    offsetX,
    offsetY,
    direction,
    isVertical,
    isHorizontal
  };
}
var style$1 = "";
const SwiperDots$1 = defineComponent({
  props: {
    prefixCls: String,
    total: {
      type: Number,
      default: 0
    },
    currentIndex: {
      type: Number,
      default: 0
    },
    dotType: {
      type: String,
      default: "dot"
    },
    trigger: {
      type: String,
      default: "click"
    },
    keyboard: Boolean
  },
  inheritAttrs: false,
  setup(props) {
    const {
      parentProps,
      swipeTo,
      next,
      prev
    } = useSwiperContext();
    const dotElsRef = ref([]);
    const handleClick = (current) => {
      if (props.trigger === "click") {
        swipeTo(current, {});
      }
    };
    const handleMouseenter = (current) => {
      if (props.trigger === "hover") {
        swipeTo(current, {});
      }
    };
    const handleKeydown = (e, current) => {
      switch (e.key) {
        case "Enter":
        case " ":
          e.preventDefault();
          swipeTo(current, {});
          return;
      }
      if (props.keyboard) {
        handleKeyboard(e);
      }
    };
    const handleKeyboard = (e) => {
      var _a, _b;
      if (e.shiftKey || e.altKey || e.ctrlKey || e.metaKey) {
        return;
      }
      const nodeName = (_a = document.activeElement) == null ? void 0 : _a.nodeName.toLowerCase();
      if (nodeName === "input" || nodeName === "textarea") {
        return;
      }
      const {
        code: keycode
      } = e;
      const isVerticalNext = keycode === "PageUp" || keycode === "ArrowUp";
      const isVerticalPrev = keycode === "PageDown" || keycode === "ArrowDown";
      const isHorizontalNext = keycode === "PageUp" || keycode === "ArrowRight";
      const isHorizontalPrev = keycode === "PageDown" || keycode === "ArrowLeft";
      const vertical = ((_b = parentProps.value) == null ? void 0 : _b.direction) === "vertical";
      const wantToNext = vertical ? isVerticalNext : isHorizontalNext;
      const wantToPrev = vertical ? isVerticalPrev : isHorizontalPrev;
      if (!wantToNext && !wantToPrev) {
        return;
      }
      e.preventDefault();
      if (wantToNext) {
        next();
      } else if (wantToPrev) {
        prev();
      }
    };
    onBeforeUpdate(() => dotElsRef.value.length = 0);
    return () => {
      return createVNode("div", {
        "class": [`${props.prefixCls}-dots`, `${props.prefixCls}-dots-${props.dotType}`, `${props.prefixCls}-dots-${unref(parentProps).dotPlacement}`, {
          [`${props.prefixCls}-show-arrow`]: unref(parentProps).showArrow
        }],
        "role": "tablist"
      }, [indexMap(props.total).map((i) => {
        const selected = i === props.currentIndex;
        return createVNode("div", {
          "aria-selected": selected,
          "ref": (el) => dotElsRef.value.push(el),
          "class": [`${props.prefixCls}-dot`, selected && `${props.prefixCls}-dot-active`],
          "role": "button",
          "tabindex": "0",
          "key": i,
          "onClick": () => handleClick(i),
          "onMouseenter": () => handleMouseenter(i),
          "onKeydown": (e) => handleKeydown(e, i)
        }, null);
      })]);
    };
  }
});
var style = "";
const backwardIcon = createVNode("svg", {
  "xmlns": "http://www.w3.org/2000/svg",
  "viewBox": "0 0 16 16"
}, [createVNode("g", {
  "fill": "none"
}, [createVNode("path", {
  "d": "M10.26 3.2a.75.75 0 0 1 .04 1.06L6.773 8l3.527 3.74a.75.75 0 1 1-1.1 1.02l-4-4.25a.75.75 0 0 1 0-1.02l4-4.25a.75.75 0 0 1 1.06-.04z",
  "fill": "currentColor"
}, null)])]);
const forwardIcon = createVNode("svg", {
  "xmlns": "http://www.w3.org/2000/svg",
  "viewBox": "0 0 16 16"
}, [createVNode("g", {
  "fill": "none"
}, [createVNode("path", {
  "d": "M5.74 3.2a.75.75 0 0 0-.04 1.06L9.227 8L5.7 11.74a.75.75 0 1 0 1.1 1.02l4-4.25a.75.75 0 0 0 0-1.02l-4-4.25a.75.75 0 0 0-1.06-.04z",
  "fill": "currentColor"
}, null)])]);
const SwiperDots = defineComponent({
  props: {
    prefixCls: String
  },
  inheritAttrs: false,
  setup(props) {
    const {
      parentProps,
      next,
      prev,
      isNextDisabled,
      isPrevDisabled
    } = useSwiperContext();
    return () => {
      return createVNode("div", {
        "class": [`${props.prefixCls}-arrow-group`, `${props.prefixCls}-arrow-${unref(parentProps).dotPlacement}`]
      }, [createVNode("div", {
        "class": [`${props.prefixCls}-arrow`, isPrevDisabled() && `${props.prefixCls}-arrow-disabled`],
        "role": "button",
        "onClick": prev
      }, [backwardIcon]), createVNode("div", {
        "class": [`${props.prefixCls}-arrow`, isNextDisabled() && `${props.prefixCls}-arrow-disabled`],
        "role": "button",
        "onClick": next
      }, [forwardIcon])]);
    };
  }
});
function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
const Swiper = defineComponent({
  name: "GSwiper",
  inheritAttrs: false,
  props: swiperPorps,
  emits: ["change", "update:currentIndex"],
  setup(props, {
    slots,
    emit,
    expose
  }) {
    const prefixCls = getPrefixCls({
      suffixCls: "swiper"
    });
    const widthRef = ref(window.innerWidth);
    const heightRef = ref(window.innerHeight);
    const root = ref();
    const track = ref();
    const touch = useTouch();
    const children = ref([]);
    const state = reactive({
      rect: null,
      width: 0,
      height: 0,
      offset: 0,
      active: props.defaultIndex,
      swiping: false
    });
    const isVertical = computed(() => props.direction === "vertical");
    const count = computed(() => children.value.length);
    const size = computed(() => state[isVertical.value ? "height" : "width"]);
    const delta = computed(() => isVertical.value ? touch.deltaY.value : touch.deltaX.value);
    const minOffset = computed(() => {
      var _a, _b;
      if (state.rect) {
        const base = isVertical.value ? ((_a = state.rect) == null ? void 0 : _a.height) || 0 : ((_b = state.rect) == null ? void 0 : _b.width) || 0;
        return numSum(base - size.value * count.value, props.spaceBetween);
      }
      return 0;
    });
    const maxCount = computed(() => size.value ? Math.ceil(Math.abs(minOffset.value) / size.value) : count.value);
    const trackSize = computed(() => count.value * size.value);
    const activeIndicator = computed(() => {
      return count.value ? (state.active + count.value) % count.value : 0;
    });
    const isCorrectDirection = computed(() => {
      const expect = isVertical.value ? "vertical" : "horizontal";
      return touch.direction.value === expect;
    });
    const trackStyle = computed(() => {
      if (props.effect === "fade")
        return void 0;
      const style2 = {
        transitionDuration: `${state.swiping ? 0 : props.duration}ms`,
        transform: `translate${isVertical.value ? "Y" : "X"}(${state.offset}px)`
      };
      if (size.value) {
        const mainAxis = isVertical.value ? "height" : "width";
        style2[mainAxis] = `${trackSize.value}px`;
        if (props.spaceBetween) {
          style2[mainAxis] = `${trackSize.value + count.value * props.spaceBetween}px`;
        }
      }
      return style2;
    });
    const slideStyle = computed(() => {
      return props.effect === "slide" ? void 0 : {
        transitionDuration: `${state.swiping ? 0 : props.duration}ms`
      };
    });
    const slidesControlListenersRef = computed(() => {
      return {
        onTouchstartPassive: props.touchable ? onTouchStart : void 0,
        onMousedown: props.draggable ? onTouchStart : void 0
      };
    });
    const isActive = (slideOrIndex) => {
      return activeIndicator.value === getSlideIndex(slideOrIndex);
    };
    const isPrevDisabled = () => {
      return props.loop ? false : activeIndicator.value === 0;
    };
    const isNextDisabled = () => {
      return props.loop ? false : activeIndicator.value + 1 === count.value;
    };
    function getSlideIndex(slideOrIndex) {
      return typeof slideOrIndex === "number" ? slideOrIndex : slideOrIndex ? children.value.map((el) => el.ref).indexOf(slideOrIndex) : -1;
    }
    const getTargetActive = (pace) => {
      const {
        active
      } = state;
      if (pace) {
        if (props.loop) {
          const currentActive = clamp(active + pace, -1, count.value);
          return props.effect === "slide" ? currentActive : currentActive >= count.value ? 0 : Math.abs(currentActive);
        }
        return clamp(active + pace, 0, maxCount.value);
      }
      return active;
    };
    const getTargetOffset = (targetActive, offset = 0) => {
      let currentPosition = targetActive * size.value;
      if (!props.loop) {
        currentPosition = Math.min(currentPosition, -minOffset.value);
      }
      let targetOffset = offset - currentPosition;
      if (!props.loop) {
        targetOffset = clamp(targetOffset, minOffset.value, 0);
      }
      return targetOffset;
    };
    const getPace = () => {
      const offset = isVertical.value ? touch.offsetY.value : touch.offsetX.value;
      let pace = 0;
      if (props.loop) {
        pace = offset > 0 ? delta.value > 0 ? -1 : 1 : 0;
      } else {
        pace = -Math[delta.value > 0 ? "ceil" : "floor"](delta.value / size.value);
      }
      return pace;
    };
    const getNextOffset = () => {
      const targetActive = getTargetActive(getPace());
      let targetOffset = getTargetOffset(targetActive, 0);
      if (targetOffset > 0 && props.spaceBetween && targetActive !== 0) {
        targetOffset = targetOffset + Math.abs(targetActive) * props.spaceBetween;
      } else if (props.spaceBetween && targetActive !== 0 ? 2 : 0) {
        targetOffset = targetOffset - Math.abs(targetActive) * props.spaceBetween;
      }
      return targetOffset;
    };
    const getStartMoveType = (pace, offset) => {
      const targetActive = getTargetActive(pace);
      const targetOffset = getTargetOffset(targetActive, offset);
      return props.spaceBetween ? targetOffset > 0 && targetActive !== 0 ? 1 : targetActive !== 0 ? 2 : 0 : 0;
    };
    let startMove = false;
    let startType = 0;
    const move = ({
      pace = 0,
      offset = 0,
      emitChange
    }) => {
      var _a, _b, _c, _d, _e;
      if (count.value <= 1) {
        return;
      }
      const targetActive = getTargetActive(pace);
      let targetOffset = getTargetOffset(targetActive, offset);
      if (Math.abs(offset) > Math.abs(minOffset.value)) {
        targetOffset = getNextOffset();
      } else {
        if (startType === 1) {
          targetOffset = targetOffset + Math.abs(targetActive) * props.spaceBetween;
        } else if (startType === 2) {
          targetOffset = targetOffset - Math.abs(targetActive) * props.spaceBetween;
        }
      }
      if (props.effect === "slide" && props.loop) {
        if (targetOffset !== minOffset.value) {
          const outRightBound = targetOffset < minOffset.value;
          (_b = (_a = children.value[0]) == null ? void 0 : _a.setOffset) == null ? void 0 : _b.call(_a, outRightBound ? trackSize.value + count.value * props.spaceBetween : 0);
        }
        if (children.value[count.value - 1] && targetOffset !== 0) {
          const outLeftBound = targetOffset > 0;
          (_d = (_c = children.value[count.value - 1]) == null ? void 0 : _c.setOffset) == null ? void 0 : _d.call(_c, outLeftBound ? -(trackSize.value + count.value * props.spaceBetween) : 0);
        }
      }
      state.active = targetActive;
      state.offset = targetOffset;
      if (emitChange && targetActive !== state.active) {
        emit("update:currentIndex", activeIndicator.value);
        (_e = props == null ? void 0 : props.onChange) == null ? void 0 : _e.call(props, activeIndicator.value);
      }
    };
    const correctPosition = () => {
      state.swiping = true;
      if (state.active <= -1) {
        startType = getStartMoveType(count.value, 0);
        move({
          pace: count.value
        });
      } else if (state.active >= count.value) {
        startType = getStartMoveType(-count.value, 0);
        move({
          pace: -count.value
        });
      }
    };
    const prev = () => {
      correctPosition();
      touch.reset();
      doubleRaf(() => {
        state.swiping = false;
        move({
          pace: -1,
          emitChange: true
        });
      });
    };
    const next = () => {
      correctPosition();
      touch.reset();
      doubleRaf(() => {
        state.swiping = false;
        move({
          pace: 1,
          emitChange: true
        });
      });
    };
    let autoplayTimer;
    const stopAutoplay = () => clearTimeout(autoplayTimer);
    const autoplay = () => {
      stopAutoplay();
      if (props.autoplay && count.value > 1) {
        autoplayTimer = setTimeout(() => {
          next();
          autoplay();
        }, +props.interval);
      }
    };
    const initialize = (active = +(props.currentIndex || props.defaultIndex || 0)) => {
      if (!root.value) {
        return;
      }
      const cb = () => {
        if (root.value) {
          const rect = {
            width: root.value.offsetWidth,
            height: root.value.offsetHeight
          };
          state.rect = rect;
          state.width = +rect.width;
          state.height = +rect.height;
        }
        if (count.value) {
          active = Math.min(count.value - 1, active);
          if (active === -1) {
            active = count.value - 1;
          }
        }
        state.active = active;
        state.swiping = true;
        state.offset = active === 0 ? getTargetOffset(active) : numSum(getTargetOffset(active), props.spaceBetween);
        children.value.forEach((swipe) => {
          var _a;
          (_a = swipe == null ? void 0 : swipe.setOffset) == null ? void 0 : _a.call(swipe, 0);
        });
        autoplay();
      };
      if (!root.value) {
        nextTick().then(cb);
      } else {
        cb();
      }
    };
    const resize = () => initialize(state.active);
    let touchStartTime;
    const onTouchStart = (event) => {
      touch.start(event);
      touchStartTime = Date.now();
      stopAutoplay();
      correctPosition();
      if (props.touchable) {
        on(document, "touchmove", onTouchMove);
        on(document, "touchend", onTouchEnd);
        on(document, "touchcancel", onTouchEnd);
      }
      if (props.draggable) {
        on(document, "mousemove", onTouchMove);
        on(document, "mouseup", onTouchEnd);
      }
    };
    const onTouchMove = (event) => {
      if (props.touchable && state.swiping) {
        touch.move(event);
        if (isCorrectDirection.value) {
          const isEdgeTouch = !props.loop && (state.active === 0 && delta.value > 0 || state.active === count.value - 1 && delta.value < 0);
          if (!isEdgeTouch) {
            event.stopPropagation();
            if (!startMove) {
              startMove = true;
              startType = getStartMoveType(0, delta.value);
            }
            move({
              offset: delta.value
            });
          }
        }
      }
    };
    const onTouchEnd = () => {
      startMove = false;
      const duration = Date.now() - touchStartTime;
      const speed = delta.value / duration;
      const shouldSwipe = Math.abs(speed) > 0.25 || Math.abs(delta.value) > size.value / 2;
      if (shouldSwipe && isCorrectDirection.value) {
        startType = getStartMoveType(getPace(), 0);
        move({
          pace: getPace(),
          emitChange: true
        });
      } else if (delta.value) {
        startType = getStartMoveType(0, 0);
        move({
          pace: 0
        });
      }
      state.swiping = false;
      startType = 0;
      autoplay();
      resetDragStatus();
    };
    const swipeTo = (index, options = {}) => {
      correctPosition();
      touch.reset();
      doubleRaf(() => {
        let targetIndex;
        if (props.loop && index === count.value) {
          targetIndex = state.active === 0 ? 0 : index;
        } else {
          targetIndex = index % count.value;
        }
        if (options.immediate) {
          doubleRaf(() => {
            state.swiping = false;
          });
        } else {
          state.swiping = false;
        }
        move({
          pace: targetIndex - state.active,
          emitChange: true
        });
      });
    };
    const handleLayouts = () => {
      widthRef.value = window.innerWidth;
      heightRef.value = window.innerHeight;
    };
    const resetDragStatus = () => {
      off(document, "touchmove", onTouchMove);
      off(document, "touchend", onTouchEnd);
      off(document, "touchcancel", onTouchEnd);
      off(document, "mousemove", onTouchMove);
      off(document, "mouseup", onTouchEnd);
      window.removeEventListener("resize", handleLayouts);
    };
    watch(() => props.currentIndex, (val) => {
      initialize(val || 0);
    });
    watch(count, () => initialize(state.active));
    watch(() => props.autoplay, autoplay);
    watch([widthRef, heightRef], resize);
    onMountedOrActivated(() => {
      window.addEventListener("resize", handleLayouts);
      initialize();
    });
    onUnmounted(() => {
      stopAutoplay();
      resetDragStatus();
    });
    onDeactivated(() => {
      stopAutoplay();
      resetDragStatus();
    });
    onBeforeUnmount(stopAutoplay);
    provideSwiperContext({
      size,
      parentProps: computed(() => props),
      children,
      slideStyle,
      isActive,
      getSlideIndex,
      swipeTo,
      prev,
      next,
      isPrevDisabled,
      isNextDisabled
    });
    expose({
      prev,
      next,
      state,
      resize,
      swipeTo
    });
    return () => {
      var _a;
      const renderDotsSlots = getSlot(slots, props, "dots");
      const renderArrowSlots = getSlot(slots, props, "arrow");
      const defaultChildren = slots.default && flatten((_a = slots.default) == null ? void 0 : _a.call(slots)) || [];
      let slides = filterCarouselItem(defaultChildren);
      if (!slides.length) {
        slides = defaultChildren.map((child) => {
          let _slot;
          return createVNode(SwiperItem, {
            "className": prefixCls
          }, _isSlot(_slot = cloneVNode(child, {
            draggable: false
          })) ? _slot : {
            default: () => [_slot]
          });
        });
      }
      return createVNode("div", mergeProps({
        "ref": root,
        "class": [prefixCls, `${prefixCls}-${props.effect}`]
      }, slidesControlListenersRef.value), [createVNode("div", {
        "ref": track,
        "class": [`${prefixCls}-content`, {
          [`${prefixCls}-vertical`]: isVertical.value
        }],
        "style": trackStyle.value
      }, [slides]), props.showDots && count.value > 1 && createVNode(Fragment, null, [renderDotsSlots ? renderDotsSlots({
        total: count.value,
        currentIndex: activeIndicator.value,
        to: swipeTo
      }) : createVNode(SwiperDots$1, {
        "prefixCls": prefixCls,
        "key": props.dotType + props.dotPlacement,
        "total": count.value,
        "currentIndex": activeIndicator.value,
        "dotType": props.dotType,
        "trigger": props.trigger,
        "keyboard": props.keyboard
      }, null)]), props.showArrow && createVNode(Fragment, null, [renderArrowSlots ? renderArrowSlots({
        total: count.value,
        currentIndex: activeIndicator.value,
        to: swipeTo,
        next,
        prev
      }) : createVNode(SwiperDots, {
        "prefixCls": prefixCls
      }, null)])]);
    };
  }
});
Swiper.install = (app) => {
  app.component(Swiper.name, Swiper);
  return app;
};
export { Swiper as GSwiper, Swiper as default, swiperPorps };
